pub fn should_run_external_learning(conn: &Connection) -> boolExpand description
Check whether external learning is enabled and under the daily cap.
pub fn should_run_external_learning(conn: &Connection) -> boolCheck whether external learning is enabled and under the daily cap.