pub fn compute_egl(conn: &Connection, date: &str) -> Result<f64>Expand description
System-wide EGL based on global metrics for the current day.
pub fn compute_egl(conn: &Connection, date: &str) -> Result<f64>System-wide EGL based on global metrics for the current day.